@@ -1,4 +1,4 @@
-from tensorfn.config.config import Config
+from tensorfn.config.config import Config, get_model, config_model
 from tensorfn.config.optimizer import Optimizer, make_optimizer
 from tensorfn.config.lr_scheduler import Scheduler
 from tensorfn.config.data import DataLoader, make_dataloader
